@@ -187,20 +187,12 @@ load_desktop (const gchar *prefix,
 	      const gchar *icons_dir,
 	      guint        min_icon_size,
 	      const gchar *app_name,
-	      const gchar *appdata_id,
+	      const gchar *desktop_path,
 	      GError **error)
 {
 	AsIcon *icon;
-	g_autofree gchar *desktop_basename = NULL;
-	g_autofree gchar *desktop_path = NULL;
 	g_autoptr(AsApp) app = NULL;
 
-	if (appdata_id != NULL)
-		desktop_basename = g_strdup (appdata_id);
-	else
-		desktop_basename = g_strconcat (app_name, ".desktop", NULL);
-	desktop_path = g_build_filename (prefix, "share/applications", desktop_basename, NULL);
-
 	app = as_app_new ();
 	if (!as_app_parse_file (app, desktop_path,
 				AS_APP_PARSE_FLAG_USE_HEURISTICS |
@@ -246,10 +238,33 @@ load_desktop (const gchar *prefix,
 	return g_steal_pointer (&app);
 }
 
+static gchar *
+get_appdata_filename (const gchar *prefix, const gchar *app_name)
+{
+	const gchar *dirs[] = { "metainfo", "appdata", NULL };
+	const gchar *exts[] = { ".metainfo.xml", ".appdata.xml", NULL };
+
+	/* fall back to the legacy path and extensions */
+	for (guint j = 0; dirs[j] != NULL; j++) {
+		for (guint i = 0; exts[i] != NULL; i++) {
+			g_autofree gchar *basename = NULL;
+			g_autofree gchar *tmp = NULL;
+			basename = g_strconcat (app_name, exts[i], NULL);
+			tmp = g_build_filename (prefix,
+						"share",
+						dirs[j],
+						basename,
+						NULL);
+			if (g_file_test (tmp, G_FILE_TEST_EXISTS))
+				return g_steal_pointer (&tmp);
+		}
+	}
+	return NULL;
+}
+
 static AsApp *
 load_appdata (const gchar *prefix, const gchar *app_name, GError **error)
 {
-	g_autofree gchar *appdata_basename = NULL;
 	g_autofree gchar *appdata_path = NULL;
 	g_autoptr(AsApp) app = NULL;
 	g_autoptr(GPtrArray) problems = NULL;
@@ -257,23 +272,7 @@ load_appdata (const gchar *prefix, const gchar *app_name, GError **error)
 	AsProblem *problem;
 	guint i;
 
-	appdata_basename = g_strconcat (app_name,
-					".appdata.xml",
-					NULL);
-	appdata_path = g_build_filename (prefix,
-					 "share",
-					 "metainfo",
-					 appdata_basename,
-					 NULL);
-	/* fall back to the legacy path */
-	if (!g_file_test (appdata_path, G_FILE_TEST_EXISTS)) {
-		g_free (appdata_path);
-		appdata_path = g_build_filename (prefix,
-						 "share",
-						 "appdata",
-						 appdata_basename,
-						 NULL);
-	}
+	appdata_path = get_appdata_filename (prefix, app_name);
 	g_debug ("Looking for %s", appdata_path);
 
 	app = as_app_new ();
@@ -407,6 +406,9 @@ main (int argc, char **argv)
 		g_auto(GStrv) intl_domains = NULL;
 		g_autoptr(AsApp) app_appdata = NULL;
 		g_autoptr(AsApp) app_desktop = NULL;
+		g_autofree gchar *desktop_basename = NULL;
+		g_autofree gchar *desktop_path = NULL;
+		const gchar *appdata_id;
 
 		/* TRANSLATORS: we're generating the AppStream data */
 		g_print ("%s %s\n", _("Processing application"), app_name);
@@ -457,20 +459,29 @@ main (int argc, char **argv)
 
 		as_store_add_app (store, app_appdata);
 
-		app_desktop = load_desktop (prefix,
-					    icons_dir,
-					    min_icon_size,
-					    app_name,
-					    as_app_get_id (app_appdata),
-					    &error);
-		if (app_desktop == NULL) {
-			/* TRANSLATORS: the .desktop file could not
-			 * be loaded */
-			g_print ("%s: %s\n", _("Error loading desktop file"),
-				 error->message);
-			return EXIT_FAILURE;
+		appdata_id = as_app_get_id (app_appdata);
+		if (appdata_id != NULL)
+			desktop_basename = g_strdup (appdata_id);
+		else
+			desktop_basename = g_strconcat (app_name, ".desktop", NULL);
+		desktop_path = g_build_filename (prefix, "share/applications", desktop_basename, NULL);
+
+		if (g_file_test (desktop_path, G_FILE_TEST_EXISTS)) {
+			app_desktop = load_desktop (prefix,
+						    icons_dir,
+						    min_icon_size,
+						    app_name,
+						    desktop_path,
+						    &error);
+			if (app_desktop == NULL) {
+				/* TRANSLATORS: the .desktop file could not
+				 * be loaded */
+				g_print ("%s: %s\n", _("Error loading desktop file"),
+					 error->message);
+				return EXIT_FAILURE;
+			}
+			as_store_add_app (store, app_desktop);
 		}
-		as_store_add_app (store, app_desktop);
 	}
 
 	/* create output directory */
