@@ -29,30 +29,16 @@
 
 #include "asb-package.h"
 
-#define ASB_TYPE_PACKAGE_CAB		(asb_package_cab_get_type())
-#define ASB_PACKAGE_CAB(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ASB_TYPE_PACKAGE_CAB, AsbPackageCab))
-#define ASB_PACKAGE_CAB_CLASS(cls)	(G_TYPE_CHECK_CLASS_CAST((cls), ASB_TYPE_PACKAGE_CAB, AsbPackageCabClass))
-#define ASB_IS_PACKAGE_CAB(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ASB_TYPE_PACKAGE_CAB))
-#define ASB_IS_PACKAGE_CAB_CLASS(cls)	(G_TYPE_CHECK_CLASS_TYPE((cls), ASB_TYPE_PACKAGE_CAB))
-#define ASB_PACKAGE_CAB_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ASB_TYPE_PACKAGE_CAB, AsbPackageCabClass))
-
 G_BEGIN_DECLS
 
-typedef struct _AsbPackageCab		AsbPackageCab;
-typedef struct _AsbPackageCabClass	AsbPackageCabClass;
-
-struct _AsbPackageCab
-{
-	AsbPackage			parent;
-};
+#define ASB_TYPE_PACKAGE_CAB (asb_package_cab_get_type ())
+G_DECLARE_DERIVABLE_TYPE (AsbPackageCab, asb_package_cab, ASB, PACKAGE_CAB, GObject)
 
 struct _AsbPackageCabClass
 {
 	AsbPackageClass			parent_class;
 };
 
-GType		 asb_package_cab_get_type	(void);
-
 AsbPackage	*asb_package_cab_new		(void);
 
 G_END_DECLS
