@@ -35,6 +35,8 @@ asb_plugin_add_globs (AsbPlugin *plugin, GPtrArray *globs)
 {
 	asb_plugin_add_glob (globs, "/usr/share/appdata/*.metainfo.xml");
 	asb_plugin_add_glob (globs, "/usr/share/appdata/*.appdata.xml");
+	asb_plugin_add_glob (globs, "/usr/share/metainfo/*.metainfo.xml");
+	asb_plugin_add_glob (globs, "/usr/share/metainfo/*.appdata.xml");
 }
 
 static gboolean
@@ -42,7 +44,9 @@ _asb_plugin_check_filename (const gchar *filename)
 {
 	if (asb_plugin_match_glob ("*.metainfo.xml", filename) ||
 	    asb_plugin_match_glob ("/usr/share/appdata/*.metainfo.xml", filename) ||
-	    asb_plugin_match_glob ("/usr/share/appdata/*.appdata.xml", filename))
+	    asb_plugin_match_glob ("/usr/share/appdata/*.appdata.xml", filename) ||
+	    asb_plugin_match_glob ("/usr/share/metainfo/*.metainfo.xml", filename) ||
+	    asb_plugin_match_glob ("/usr/share/metainfo/*.appdata.xml", filename))
 		return TRUE;
 	return FALSE;
 }
