@@ -30,6 +30,7 @@
 
 #include "as-app.h"
 #include "as-node-private.h"
+#include "as-stemmer.h"
 
 G_BEGIN_DECLS
 
@@ -112,6 +113,12 @@ gboolean	 as_app_parse_inf_file		(AsApp		*app,
 						 const gchar	*filename,
 						 AsAppParseFlags flags,
 						 GError		**error);
+void		 as_app_set_stemmer		(AsApp		*app,
+						 AsStemmer	*stemmer);
+void		 as_app_set_search_blacklist	(AsApp		*app,
+						 GHashTable	*search_blacklist);
+void		 as_app_set_search_match	(AsApp		*app,
+						 AsAppSearchMatch search_match);
 
 G_END_DECLS
 
