@@ -34,6 +34,7 @@
 #include "as-provide.h"
 #include "as-release.h"
 #include "as-screenshot.h"
+#include "as-require.h"
 #include "as-review.h"
 #include "as-suggest.h"
 #include "as-content-rating.h"
@@ -338,6 +339,7 @@ typedef enum {
  * @AS_APP_QUIRK_NOT_LAUNCHABLE:	The app is not launchable (run-able)
  * @AS_APP_QUIRK_NEEDS_USER_ACTION:	The component requires some kind of user action
  * @AS_APP_QUIRK_IS_PROXY:		Is a proxy app that operates on other applications
+ * @AS_APP_QUIRK_REMOVABLE_HARDWARE:	The device is unusable whilst the action is performed
  *
  * The component attributes.
  **/
@@ -353,6 +355,7 @@ typedef enum {
 	AS_APP_QUIRK_NOT_LAUNCHABLE	= 1 << 7,	/* Since: 0.5.15 */
 	AS_APP_QUIRK_NEEDS_USER_ACTION	= 1 << 8,	/* Since: 0.6.2 */
 	AS_APP_QUIRK_IS_PROXY 		= 1 << 9,	/* Since: 0.6.6 */
+	AS_APP_QUIRK_REMOVABLE_HARDWARE	= 1 << 10,	/* Since: 0.6.6 */
 	/*< private >*/
 	AS_APP_QUIRK_LAST
 } AsAppQuirk;
@@ -495,6 +498,7 @@ GPtrArray	*as_app_get_icons		(AsApp		*app);
 GPtrArray	*as_app_get_bundles		(AsApp		*app);
 GPtrArray	*as_app_get_translations	(AsApp		*app);
 GPtrArray	*as_app_get_suggests		(AsApp		*app);
+GPtrArray	*as_app_get_requires		(AsApp		*app);
 GHashTable	*as_app_get_names		(AsApp		*app);
 GHashTable	*as_app_get_comments		(AsApp		*app);
 GHashTable	*as_app_get_developer_names	(AsApp		*app);
@@ -626,6 +630,8 @@ void		 as_app_add_translation		(AsApp		*app,
 						 AsTranslation	*translation);
 void		 as_app_add_suggest		(AsApp		*app,
 						 AsSuggest	*suggest);
+void		 as_app_add_require		(AsApp		*app,
+						 AsRequire	*require);
 void		 as_app_add_language		(AsApp		*app,
 						 gint		 percentage,
 						 const gchar	*locale);
@@ -683,6 +689,9 @@ AsBundle	*as_app_get_bundle_default	(AsApp		*app);
 AsRelease	*as_app_get_release		(AsApp		*app,
 						 const gchar	*version);
 AsRelease	*as_app_get_release_default	(AsApp		*app);
+AsRequire	*as_app_get_require_by_value	(AsApp		*app,
+						 AsRequireKind	 kind,
+						 const gchar	*value);
 gboolean	 as_app_convert_icons		(AsApp		*app,
 						 AsIconKind	 kind,
 						 GError		**error);
