@@ -34,16 +34,17 @@
 
 #include "as-node-private.h"
 #include "as-content-rating-private.h"
+#include "as-ref-string.h"
 #include "as-tag.h"
 
 typedef struct {
-	gchar			*id;
+	AsRefString		*id;
 	AsContentRatingValue	 value;
 } AsContentRatingKey;
 
 typedef struct
 {
-	gchar			*kind;
+	AsRefString		*kind;
 	GPtrArray		*keys; /* of AsContentRatingKey */
 } AsContentRatingPrivate;
 
@@ -57,7 +58,8 @@ as_content_rating_finalize (GObject *object)
 	AsContentRating *content_rating = AS_CONTENT_RATING (object);
 	AsContentRatingPrivate *priv = GET_PRIVATE (content_rating);
 
-	g_free (priv->kind);
+	if (priv->kind != NULL)
+		as_ref_string_unref (priv->kind);
 	g_ptr_array_unref (priv->keys);
 
 	G_OBJECT_CLASS (as_content_rating_parent_class)->finalize (object);
@@ -66,8 +68,9 @@ as_content_rating_finalize (GObject *object)
 static void
 as_content_rating_key_free (AsContentRatingKey *key)
 {
-	g_free (key->id);
-	g_free (key);
+	if (key->id != NULL)
+		as_ref_string_unref (key->id);
+	g_slice_free (AsContentRatingKey, key);
 }
 
 static void
@@ -84,6 +87,30 @@ as_content_rating_class_init (AsContentRatingClass *klass)
 	object_class->finalize = as_content_rating_finalize;
 }
 
+/**
+ * as_content_rating_get_value:
+ * @content_rating: a #AsContentRating
+ * @id: A ratings ID, e.g. `violence-bloodshed`.
+ *
+ * Gets the set value of a content rating key.
+ *
+ * Returns: the #AsContentRatingValue, or %AS_CONTENT_RATING_VALUE_UNKNOWN
+ *
+ * Since: 0.6.4
+ **/
+AsContentRatingValue
+as_content_rating_get_value (AsContentRating *content_rating, const gchar *id)
+{
+	AsContentRatingPrivate *priv = GET_PRIVATE (content_rating);
+	guint i;
+	for (i = 0; i < priv->keys->len; i++) {
+		AsContentRatingKey *key = g_ptr_array_index (priv->keys, i);
+		if (g_strcmp0 (key->id, id) == 0)
+			return key->value;
+	}
+	return AS_CONTENT_RATING_VALUE_UNKNOWN;
+}
+
 /**
  * as_content_rating_value_to_string:
  * @value: the #AsContentRatingValue.
@@ -243,7 +270,7 @@ as_content_rating_id_value_to_csm_age (const gchar *id, AsContentRatingValue val
  * here. Some 13 year olds mey be fine with the concept of mutilation of body
  * parts, others may get nightmares.
  *
- * Returns: The age in years, or G_MAXUINT for no details.
+ * Returns: The age in years, 0 for no rating, or G_MAXUINT for no details.
  *
  * Since: 0.5.12
  **/
@@ -252,7 +279,7 @@ as_content_rating_get_minimum_age (AsContentRating *content_rating)
 {
 	AsContentRatingPrivate *priv = GET_PRIVATE (content_rating);
 	guint i;
-	guint csm_age = G_MAXUINT;
+	guint csm_age = 0;
 
 	/* check kind */
 	if (g_strcmp0 (priv->kind, "oars-1.0") != 0)
@@ -263,7 +290,7 @@ as_content_rating_get_minimum_age (AsContentRating *content_rating)
 		guint csm_tmp;
 		key = g_ptr_array_index (priv->keys, i);
 		csm_tmp = as_content_rating_id_value_to_csm_age (key->id, key->value);
-		if (csm_tmp > 0 && csm_tmp < csm_age)
+		if (csm_tmp > 0 && csm_tmp > csm_age)
 			csm_age = csm_tmp;
 	}
 	return csm_age;
@@ -299,8 +326,7 @@ void
 as_content_rating_set_kind (AsContentRating *content_rating, const gchar *kind)
 {
 	AsContentRatingPrivate *priv = GET_PRIVATE (content_rating);
-	g_free (priv->kind);
-	priv->kind = g_strdup (kind);
+	as_ref_string_assign_safe (&priv->kind, kind);
 }
 
 /**
@@ -375,8 +401,8 @@ as_content_rating_node_parse (AsContentRating *content_rating, GNode *node,
 		g_autoptr(AsImage) image = NULL;
 		if (as_node_get_tag (c) != AS_TAG_CONTENT_ATTRIBUTE)
 			continue;
-		key = g_new0 (AsContentRatingKey, 1);
-		key->id = as_node_take_attribute (c, "id");
+		key = g_slice_new0 (AsContentRatingKey);
+		as_ref_string_assign (&key->id, as_node_get_attribute (c, "id"));
 		key->value = as_content_rating_value_from_string (as_node_get_data (c));
 		g_ptr_array_add (priv->keys, key);
 	}
