@@ -171,6 +171,11 @@ _g_file_monitor_to_string (GFileMonitorEvent ev)
 		return "MOVED";
 	if (ev == G_FILE_MONITOR_EVENT_RENAMED)
 		return "RENAMED";
+	if (ev == G_FILE_MONITOR_EVENT_MOVED_IN)
+		return "MOVED_IN";
+	if (ev == G_FILE_MONITOR_EVENT_MOVED_OUT)
+		return "MOVED_OUT";
+	g_warning ("Failed to convert GFileMonitorEvent %u", ev);
 	return NULL;
 }
 
@@ -282,12 +287,12 @@ as_monitor_process_pending_trigger_cb (gpointer user_data)
 }
 
 static void
-as_monitor_process_pending_trigger (AsMonitor *monitor)
+as_monitor_process_pending_trigger (AsMonitor *monitor, guint timeout_ms)
 {
 	AsMonitorPrivate *priv = GET_PRIVATE (monitor);
 	if (priv->pending_id)
 		g_source_remove (priv->pending_id);
-	priv->pending_id = g_timeout_add (800,
+	priv->pending_id = g_timeout_add (timeout_ms,
 					  as_monitor_process_pending_trigger_cb,
 					  monitor);
 }
@@ -336,26 +341,35 @@ as_monitor_file_changed_cb (GFileMonitor *mon,
 
 	switch (event_type) {
 	case G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT:
-		as_monitor_process_pending (monitor);
+		as_monitor_process_pending_trigger (monitor, 50);
 		break;
 	case G_FILE_MONITOR_EVENT_CREATED:
+	case G_FILE_MONITOR_EVENT_MOVED_IN:
 		if (!is_temp) {
 			_g_ptr_array_str_add (priv->queue_add, filename);
 		} else {
 			_g_ptr_array_str_add (priv->queue_temp, filename);
 		}
 		/* file monitors do not send CHANGES_DONE_HINT */
-		as_monitor_process_pending_trigger (monitor);
+		as_monitor_process_pending_trigger (monitor, 800);
 		break;
 	case G_FILE_MONITOR_EVENT_DELETED:
-		as_monitor_emit_removed (monitor, filename);
+	case G_FILE_MONITOR_EVENT_MOVED_OUT:
+		/* only emit notifications for files we know about */
+		if (_g_ptr_array_str_find (priv->files, filename)) {
+			as_monitor_emit_removed (monitor, filename);
+		} else {
+			g_debug ("ignoring deleted file %s", filename);
+		}
 		break;
 	case G_FILE_MONITOR_EVENT_CHANGED:
+	case G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED:
 		/* if the file is not pending and not a temp file, add */
 		if (_g_ptr_array_str_find (priv->queue_add, filename) == NULL &&
 		    _g_ptr_array_str_find (priv->queue_temp, filename) == NULL) {
 			_g_ptr_array_str_add (priv->queue_changed, filename);
 		}
+		as_monitor_process_pending_trigger (monitor, 800);
 		break;
 	case G_FILE_MONITOR_EVENT_RENAMED:
 		/* a temp file that was just created and atomically
@@ -405,14 +419,16 @@ as_monitor_add_directory (AsMonitor *monitor,
 	g_autoptr(GDir) dir = NULL;
 
 	/* find the files already in the directory */
-	dir = g_dir_open (filename, 0, error);
-	if (dir == NULL)
-		return FALSE;
-	while ((tmp = g_dir_read_name (dir)) != NULL) {
-		g_autofree gchar *fn = NULL;
-		fn = g_build_filename (filename, tmp, NULL);
-		g_debug ("adding existing file: %s", fn);
-		_g_ptr_array_str_add (priv->files, fn);
+	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
+		dir = g_dir_open (filename, 0, error);
+		if (dir == NULL)
+			return FALSE;
+		while ((tmp = g_dir_read_name (dir)) != NULL) {
+			g_autofree gchar *fn = NULL;
+			fn = g_build_filename (filename, tmp, NULL);
+			g_debug ("adding existing file: %s", fn);
+			_g_ptr_array_str_add (priv->files, fn);
+		}
 	}
 
 	/* create new file monitor */
