@@ -28,11 +28,13 @@
 
 #include "as-app.h"
 #include "as-node.h"
+#include "as-ref-string.h"
 
 G_BEGIN_DECLS
 
 typedef struct _AsNodeContext	AsNodeContext;
 AsNodeContext	*as_node_context_new		(void);
+void		 as_node_context_free		(AsNodeContext	*ctx);
 gdouble		 as_node_context_get_version	(AsNodeContext	*ctx);
 void		 as_node_context_set_version	(AsNodeContext	*ctx,
 						 gdouble	 version);
@@ -49,13 +51,12 @@ const gchar	*as_node_context_get_media_base_url (AsNodeContext	*ctx);
 void		 as_node_context_set_media_base_url (AsNodeContext	*ctx,
 						     const gchar	*url);
 
-gchar		*as_node_take_data		(const GNode	*node);
-gchar		*as_node_take_attribute		(const GNode	*node,
-						 const gchar	*key);
-gchar		*as_node_reflow_text		(const gchar	*text,
+AsRefString	*as_node_reflow_text		(const gchar	*text,
 						 gssize		 text_len);
 gchar		*as_node_fix_locale		(const gchar	*locale);
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(AsNodeContext, as_node_context_free)
+
 G_END_DECLS
 
 #endif /* __AS_NODE_PRIVATE_H */
