@@ -35,11 +35,12 @@
 
 #include "as-tag.h"
 
-#ifdef HAVE_GPERF
-  /* we need to define this now as gperf just writes a big header file */
-  const struct tag_data *_as_tag_from_gperf (const char *tag, guint etag);
-  #include "as-tag-private.h"
-#endif
+const struct tag_data *_as_tag_from_gperf (const char *tag, GPERF_LEN_TYPE etag);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wconversion"
+#pragma GCC diagnostic ignored "-Wsign-conversion"
+#include "as-tag-private.h"
+#pragma GCC diagnostic pop
 
 /**
  * as_tag_from_string:
@@ -72,30 +73,17 @@ as_tag_from_string (const gchar *tag)
 AsTag
 as_tag_from_string_full (const gchar *tag, AsTagFlags flags)
 {
-#ifdef HAVE_GPERF
 	const struct tag_data *ky;
-#else
-	guint i;
-#endif
 	AsTag etag = AS_TAG_UNKNOWN;
 
 	/* invalid */
 	if (tag == NULL)
 		return AS_TAG_UNKNOWN;
 
-#ifdef HAVE_GPERF
 	/* use a perfect hash */
-	ky = _as_tag_from_gperf (tag, (guint) strlen (tag));
+	ky = _as_tag_from_gperf (tag, (GPERF_LEN_TYPE) strlen (tag));
 	if (ky != NULL)
 		etag = ky->etag;
-#else
-	for (i = 0; i < AS_TAG_LAST; i++) {
-		if (g_strcmp0 (tag, as_tag_to_string (i)) == 0) {
-			etag = i;
-			break;
-		}
-	}
-#endif
 
 	/* deprecated names */
 	if (etag == AS_TAG_UNKNOWN && (flags & AS_TAG_FLAG_USE_FALLBACKS)) {
@@ -201,6 +189,7 @@ as_tag_to_string (AsTag tag)
 		"reviewer_id",
 		"suggests",
 		"requires",
+		"custom",
 		NULL };
 	if (tag > AS_TAG_LAST)
 		tag = AS_TAG_LAST;
