@@ -200,7 +200,7 @@ as_utils_is_stock_icon_name (const gchar *name)
  *
  * Searches the known list of SPDX license IDs.
  *
- * Returns: %TRUE if the icon is a valid "SPDX license ID"
+ * Returns: %TRUE if the license ID is a valid "SPDX license ID"
  *
  * Since: 0.1.5
  **/
@@ -218,7 +218,7 @@ as_utils_is_spdx_license_id (const gchar *license_id)
 	if (g_str_has_prefix (license_id, "LicenseRef-"))
 		return TRUE;
 
-	/* load the readonly data section and look for the icon name */
+	/* load the readonly data section and look for the license ID */
 	data = g_resource_lookup_data (as_get_resource (),
 				       "/org/freedesktop/appstream-glib/as-license-ids.txt",
 				       G_RESOURCE_LOOKUP_FLAGS_NONE,
@@ -261,7 +261,7 @@ as_utils_is_environment_id (const gchar *environment_id)
 	g_autoptr(GBytes) data = NULL;
 	g_autofree gchar *key = NULL;
 
-	/* load the readonly data section and look for the icon name */
+	/* load the readonly data section and look for the environment ID */
 	data = g_resource_lookup_data (as_get_resource (),
 				       "/org/freedesktop/appstream-glib/as-environment-ids.txt",
 				       G_RESOURCE_LOOKUP_FLAGS_NONE,
@@ -288,7 +288,7 @@ as_utils_is_category_id (const gchar *category_id)
 	g_autoptr(GBytes) data = NULL;
 	g_autofree gchar *key = NULL;
 
-	/* load the readonly data section and look for the icon name */
+	/* load the readonly data section and look for the category ID */
 	data = g_resource_lookup_data (as_get_resource (),
 				       "/org/freedesktop/appstream-glib/as-category-ids.txt",
 				       G_RESOURCE_LOOKUP_FLAGS_NONE,
@@ -342,6 +342,18 @@ as_utils_spdx_license_tokenize_drop (AsUtilsSpdxHelper *helper)
 		return;
 	}
 
+	/* is license enum with "+" */
+	if (g_str_has_suffix (tmp, "+")) {
+		g_autofree gchar *license_id = g_strndup (tmp, strlen (tmp) - 1);
+		if (as_utils_is_spdx_license_id (license_id)) {
+			g_ptr_array_add (helper->array, g_strdup_printf ("@%s", license_id));
+			g_ptr_array_add (helper->array, g_strdup ("+"));
+			helper->last_token_literal = FALSE;
+			g_string_truncate (helper->collect, 0);
+			return;
+		}
+	}
+
 	/* is old license enum */
 	for (i = 0; licenses[i].old != NULL; i++) {
 		if (g_strcmp0 (tmp, licenses[i].old) != 0)
@@ -466,6 +478,10 @@ as_utils_spdx_license_detokenize (gchar **license_tokens)
 			g_string_append (tmp, " OR ");
 			continue;
 		}
+		if (g_strcmp0 (license_tokens[i], "+") == 0) {
+			g_string_append (tmp, "+");
+			continue;
+		}
 		if (license_tokens[i][0] != '@') {
 			g_string_append (tmp, license_tokens[i]);
 			continue;
@@ -482,7 +498,7 @@ as_utils_spdx_license_detokenize (gchar **license_tokens)
  * Checks the licence string to check it being a valid licence.
  * NOTE: SPDX licences can't typically contain brackets.
  *
- * Returns: %TRUE if the icon is a valid "SPDX license"
+ * Returns: %TRUE if the license is a valid "SPDX license"
  *
  * Since: 0.2.5
  **/
@@ -518,6 +534,8 @@ as_utils_is_spdx_license (const gchar *license)
 			continue;
 		if (g_strcmp0 (tokens[i], "|") == 0)
 			continue;
+		if (g_strcmp0 (tokens[i], "+") == 0)
+			continue;
 		return FALSE;
 	}
 	return TRUE;
@@ -892,7 +910,6 @@ as_utils_find_icon_filename_full (const gchar *destdir,
 				 NULL };
 	g_autofree gchar *prefix = NULL;
 
-	g_return_val_if_fail (destdir != NULL, NULL);
 	g_return_val_if_fail (search != NULL, NULL);
 
 	/* fallback */
